@@ -182,7 +182,7 @@ class JsonList(list):
 
     def __add__(self, other):
         iterable = [item for item in self] + [item for item in other]
-        return JsonList(iterable, self._allowedType)
+        return JsonList(iterable, self.list_type)
 
     def __radd__(self, other):
         iterable = [item for item in other] + [item for item in self]
@@ -219,6 +219,9 @@ class JsonList(list):
     def __str__(self):
         return "[" + ",".join([json.dumps(x) if type(x) is str else str(x) for x in self]) + "]"
 
+    def __repr__(self):
+        return str(self)
+
     def get(self, m):
         l = JsonList()
         for i in self:
